======
PyCADF
======

.. image:: https://img.shields.io/pypi/v/pycadf.svg
    :target: https://pypi.python.org/pypi/pycadf/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/pycadf.svg
    :target: https://pypi.python.org/pypi/pycadf/
    :alt: Downloads

This library provides an auditing data model based on the `Cloud Auditing Data
Federation <http://www.dmtf.org/standards/cadf>`_ specification, primarily for
use by OpenStack. The goal is to establish strict expectations about what
auditors can expect from audit notifications.

* `PyPi`_ - package installation
* `Online Documentation`_
* `Launchpad project`_ - release management
* `Blueprints`_ - feature specifications
* `Bugs`_ - issue tracking
* `Source`_

.. _PyPi: https://pypi.python.org/pypi/pycadf
.. _Online Documentation: http://docs.openstack.org/developer/pycadf/
.. _Launchpad project: https://launchpad.net/pycadf
.. _Blueprints: https://blueprints.launchpad.net/pycadf
.. _Bugs: https://bugs.launchpad.net/pycadf
.. _Source: https://git.openstack.org/cgit/openstack/pycadf
